----------------------------------------------------------------------------------------------
--
-- This patch adds CHAT_MSG_GUILD_ITEM_LOOTED to GreenWall's event listener.
-- We try to handle this in the same way GW handles the CHAT_MSG_GUILD_ACHIEVEMENT event:
-- when a rare item shows up in chat, we check if we're the player who posted it to chat,
-- and if so, post it to GreenWall in achievement format.
--
----------------------------------------------------------------------------------------------

-- First step is to hook into GreenWall_OnEvent.
-- We replace the function as soon as GW-Loot loads.
-- Check that GreenWall has correctly loaded.  It's a dependency, so it should load before we do...
if(gw and GreenWallInterfaceFrame)then
	
	-- GreenWall doesn't normally listen for CHAT_MSG_GUILD_ITEM_LOOTED, so set that up here
	GreenWallInterfaceFrame:RegisterEvent('CHAT_MSG_GUILD_ITEM_LOOTED')
	
	-- Hook into the function here.  (The remaining code won't be called until an event occurs)
	local old_GreenWall_OnEvent = GreenWall_OnEvent
	function GreenWall_OnEvent(self, event, ...)
		old_GreenWall_OnEvent(self, event, ...)
		
		-- From here, we try to emulate the existing OnEvent function as closely as possible.
		if not gw.addon_loaded then
			return
		end
		
		-- The original 'CHAT_MSG_GUILD_ACHIEVEMENT' handler is five lines long.
		-- This one gets a little more complicated.
		if event == 'CHAT_MSG_GUILD_ITEM_LOOTED' then
			local message, sender, _, _, _, flags, _, chanNum = select(1, ...)
			gw.Debug(GW_LOG_DEBUG, 'event=%s, sender=%s, message=%s', event, sender, message)			

			-- The first difference is that "sender" doesn't contain the player's realm name,
			-- so we trim gw.player's name before comparing it to sender.
			local player=gw.player
			local j=string.find(player,"-")
			if(j~=nil)then
				-- (This might cause problems on connected realms.)
				player=string.sub(player,1,j-1)
			end			
			
			-- The second difference is GreenWall expects the message to start with %s.
			-- For whatever reason, item loot announcements start with $s instead.
			message="%"..(string.sub(message,2))
			
			if gw.iCmp(sender, player) then				
				-- Then we just send the message as if it were an achievement, and we're done.
				gw.config.channel.guild:send(GW_MTYPE_ACHIEVEMENT, message)
			end	
		end
	end
else -- else gw and/or GreenWallInterfaceFrame do not exist
	print("GW-Loot couldn't start correctly because GreenWall hasn't loaded yet.")
end


